@@ -238,10 +238,9 @@ def parse_offers(p: Product, selector: parsel.Selector = None):
         "//div[@id='olpLinkWidget_feature_div']//div[@class='olp-text-box']/span[1]/text()"
     ).get()
     if offers is None:
-        p.offers = None
-        return
-
-    p.offers = parse_number(offers)
+        p.offers = 0
+    else:
+        p.offers: Union[int, None] = parse_number(offers)
 
 
 def parse_delivery(p: Product, selector: parsel.Selector = None):
